==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebGridActionButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionButtonDescription } from "./WebGridActionButtonDescription";
/**
 * @hidden
 */
export let WebGridActionButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionButtonDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionButtonDescriptionMetadata.a == null) {
                WebGridActionButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionButtonDescriptionMetadata.c(WebGridActionButtonDescriptionMetadata.a);
            }
            if (a.k(WebGridActionButtonDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridActionButtonDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionButton");
            a.item("__tagNameWC", "String:igc-grid-action-button");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("AsMenuItem", "Boolean");
            a.item("IconName", "String");
            a.item("ClassNames", "String");
            a.item("IconSet", "String");
            a.item("LabelText", "String");
        }
        static d(a) {
            WebGridActionButtonDescriptionMetadata.b(a);
            a.ad("WebGridActionButton", () => new WebGridActionButtonDescription());
            a.ac("WebGridActionButton", WebGridActionButtonDescriptionMetadata.a);
        }
    }
    WebGridActionButtonDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridActionButtonDescriptionMetadata, 'WebGridActionButtonDescriptionMetadata');
    WebGridActionButtonDescriptionMetadata.a = null;
    return WebGridActionButtonDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebGridActionButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionButtonDescription } from "./WebGridActionButtonDescription";
/**
 * @hidden
 */
export let WebGridActionButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionButtonDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionButtonDescriptionMetadata.a == null) {
                WebGridActionButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionButtonDescriptionMetadata.c(WebGridActionButtonDescriptionMetadata.a);
            }
            if (a.k(WebGridActionButtonDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridActionButtonDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionButton");
            a.item("__tagNameWC", "String:igc-grid-action-button");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("AsMenuItem", "Boolean");
            a.item("IconName", "String");
            a.item("ClassNames", "String");
            a.item("IconSet", "String");
            a.item("LabelText", "String");
        }
        static d(a) {
            WebGridActionButtonDescriptionMetadata.b(a);
            a.ae("WebGridActionButton", () => new WebGridActionButtonDescription());
            a.ad("WebGridActionButton", WebGridActionButtonDescriptionMetadata.a);
        }
    }
    WebGridActionButtonDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridActionButtonDescriptionMetadata, 'WebGridActionButtonDescriptionMetadata');
    WebGridActionButtonDescriptionMetadata.a = null;
    return WebGridActionButtonDescriptionMetadata;
})();
